@@ -28,7 +28,7 @@ import beeswarm
 from beeswarm.server.webapp.auth import Authenticator
 from beeswarm.shared.helpers import drop_privileges, send_zmq_request
 from beeswarm.server.misc.scheduler import Scheduler
-from beeswarm.shared.helpers import create_self_signed_cert, generate_cert_digest
+from beeswarm.shared.helpers import create_self_signed_cert, generate_cert_digest, stop_if_not_write_workdir
 from beeswarm.shared.asciify import asciify
 from beeswarm.server.db.session_persister import SessionPersister
 from beeswarm.server.misc.config_actor import ConfigActor
@@ -212,8 +212,8 @@ class Server(object):
             self.workers['maintenance'] = maintenance_greenlet
             self.greenlets.append(maintenance_greenlet)
 
-        drop_privileges()
-        logger.info('Server started and priviliges dropped.')
+        stop_if_not_write_workdir(self.work_dir)
+        logger.info('Server started.')
         gevent.joinall(self.greenlets)
 
     def stop(self):
@@ -334,7 +334,7 @@ class Server(object):
             else:
                 assert False
 
-            socket.send('{0} {1}'.format(Messages.SET, json.dumps({'network': {'zmq_server_public_key': zmq_public,
+            socket.send('{0} {1}'.format(Messages.SET_CONFIG_ITEM, json.dumps({'network': {'zmq_server_public_key': zmq_public,
                                                                                'web_port': web_port,
                                                                                'zmq_port': zmq_port,
                                                                                'zmq_command_port': zmq_command_port,
